==> qtjambi-remoteobjects-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiRemoteObjects/QConnectionAbstractServer_shell.h <==
#ifndef QCONNECTIONABSTRACTSERVER_SHELL_H
#define QCONNECTIONABSTRACTSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtRemoteObjects/5.15.2/QtRemoteObjects/private/qconnectionfactories_p.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNetwork/qabstractsocket.h>
#include <QtJambi/RegistryAPI>


class QConnectionAbstractServer_shell : public QConnectionAbstractServer, public QtJambiShellInterface
{
public:
    QConnectionAbstractServer_shell(QObject* parent0 = nullptr);
    ~QConnectionAbstractServer_shell() override;

    QUrl address() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    ServerIoDevice* configureNewConnection() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasPendingConnections() const override;
    bool listen(const QUrl& address0) override;
    QAbstractSocket::SocketError serverError() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QConnectionAbstractServer_access : public QConnectionAbstractServer
{
    jobject __qt_address(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_configureNewConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_hasPendingConnections(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_listen_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID address0);
    jint __qt_serverError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QCONNECTIONABSTRACTSERVER_SHELL_H

==> qtjambi-remoteobjects-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiRemoteObjects/QConnectionAbstractServer_shell.h <==
#ifndef QCONNECTIONABSTRACTSERVER_SHELL_H
#define QCONNECTIONABSTRACTSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qconnectionfactories.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtNetwork/qabstractsocket.h>
#include <QtJambi/RegistryAPI>


class QConnectionAbstractServer_shell : public QConnectionAbstractServer, public QtJambiShellInterface
{
public:
    QConnectionAbstractServer_shell(QObject* parent0 = nullptr);
    ~QConnectionAbstractServer_shell() override;

    QUrl address() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    QtROServerIoDevice* configureNewConnection() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasPendingConnections() const override;
    bool listen(const QUrl& address0) override;
    QAbstractSocket::SocketError serverError() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QConnectionAbstractServer_access : public QConnectionAbstractServer
{
    jobject __qt_address(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_configureNewConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_hasPendingConnections(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_listen_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID address0);
    jint __qt_serverError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QCONNECTIONABSTRACTSERVER_SHELL_H
